pytest-dbfixtures
=================

.. image:: https://pypip.in/v/pytest-dbfixtures/badge.png
    :target: https://pypi.python.org/pypi/pytest-dbfixtures/
    :alt: Latest PyPI version

.. image:: https://readthedocs.org/projects/pytest-dbfixtures/badge/?version=v0.13.1
    :target: https://readthedocs.org/projects/pytest-dbfixtures/?badge=v0.13.1
    :alt: Documentation Status

.. image:: https://pypip.in/d/pytest-dbfixtures/badge.png
    :target: https://pypi.python.org/pypi/pytest-dbfixtures/
    :alt: Number of PyPI downloads

.. image:: https://pypip.in/wheel/pytest-dbfixtures/badge.png
    :target: https://pypi.python.org/pypi/pytest-dbfixtures/
    :alt: Wheel Status

.. image:: https://pypip.in/egg/pytest-dbfixtures/badge.png
    :target: https://pypi.python.org/pypi/pytest-dbfixtures/
    :alt: Egg Status

.. image:: https://pypip.in/license/pytest-dbfixtures/badge.png
    :target: https://pypi.python.org/pypi/pytest-dbfixtures/
    :alt: License

Package status
--------------

.. image:: https://travis-ci.org/ClearcodeHQ/pytest-dbfixtures.svg?branch=v0.13.1
    :target: https://travis-ci.org/ClearcodeHQ/pytest-dbfixtures
    :alt: Tests

.. image:: https://coveralls.io/repos/ClearcodeHQ/pytest-dbfixtures/badge.png?branch=v0.13.1
    :target: https://coveralls.io/r/ClearcodeHQ/pytest-dbfixtures?branch=v0.13.1
    :alt: Coverage Status

.. image:: https://requires.io/github/ClearcodeHQ/pytest-dbfixtures/requirements.svg?tag=v0.13.1
     :target: https://requires.io/github/ClearcodeHQ/pytest-dbfixtures/requirements/?tag=v0.13.1
     :alt: Requirements Status

Overview
--------

py.test clean fixtures for: ``postgresql``, ``mysql``, ``redis``, ``mongo``, ``elasticsearch`` and ``rabbitmq``.

Starts specific database deamon and cleanup all data produced during tests.


Install
-------

.. sourcecode:: bash

    $ pip install --upgrade pytest-dbfixtures


How to use
----------

Please see `documentation <http://pytest-dbfixtures.readthedocs.org/en/latest/howtouse.html>`_
